@@ -2,18 +2,21 @@ import time
 import functools
 import sys
 from importlib import reload
-import tensorflow as tf
+
 
 def show_gpuinfo():
-    print("gpu list:",tf.config.list_physical_devices('GPU'))
-    print("n of GPUs Available: ", len(tf.config.experimental.list_physical_devices('GPU')))
+    import tensorflow as tf
+    print("gpu list:", tf.config.list_physical_devices('GPU'))
+    print("n of GPUs Available: ", len(
+        tf.config.experimental.list_physical_devices('GPU')))
     sys_details = tf.sysconfig.get_build_info()
     try:
         cuda_version = sys_details["cuda_version"]
-        print("cuda_version:",cuda_version)
+        print("cuda_version:", cuda_version)
     except:
         print("no cuda")
 
+
 def say_hello():
     print("hello this is fummytransformers!")
 
